/***********************************************************************************
 * LabTestSim - Laboratory Test Simulator using Elastoplastic models               *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>     *
 *                                                                                 *
 * This file is part of LabTestSim.                                                *
 *                                                                                 *
 * LabTestSim is free software; you can redistribute it and/or modify it under the *
 * terms of the GNU General Public License as published by the Free Software       *
 * Foundation; either version 2 of the License, or (at your option) any later      *
 * version.                                                                        *
 *                                                                                 *
 * LabTestSim is distributed in the hope that it will be useful, but WITHOUT ANY   *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.        *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License along with    *
 * LabTestSim; if not, write to the Free Software Foundation, Inc., 51 Franklin    *
 * Street, Fifth Floor, Boston, MA 02110-1301, USA                                 *
 ***********************************************************************************/

#ifndef LABTESTSIM_LABTESTSIM_H
#define LABTESTSIM_LABTESTSIM_H

#include <iostream>
#include <string>
#include <vector>

// external
#include "mechsys/parameters/parameters.h"
#include "mechsys/models/model.h"

enum TestKey {NON=0,CTX=100,CTP=101,CTA=102,CTR=103,TTX=104,TTP=105,HCY=106,PSA=107};

class LabTestSim
{

	friend std::ostream & operator<< (std::ostream & os, const LabTestSim & lts);

public:

	bool Set(const char          * strTestKey,
		     MechSys::Parameters * Prms,
		     MechSys::Model      * Model,
		     std::string           PatFileName,
		     int                   NumStep,
		     int                   OutStep,
			 double                MaxEdPct);

	bool RunTest();
	
	std::string GetErrors() { return _str_errors; }

private:
	TestKey                       _key;        // Test type
	MechSys::Model              * _model;      // Constitutive model
	int                           _num_step;   // Number of steps
	int                           _out_step;   // Output number
	int                           _num_path;   // Number of stress/strain states
	std::vector<double>           _path_Sa;    // Only the final state
	std::vector<double>           _path_Sr;    // Only the final state
	std::vector<double>           _path_XX;    // Ea, Er, St, Eat; at final state
	std::vector<MechSys::Tensr2>  _sig;        // Stress
	std::vector<MechSys::Tensr2>  _eps;        // Strain
	std::string                   _str_errors; // Errors messages
	double                        _max_ed;     // Maximum value of deviatoric strain
	std::vector<double>           _sgnX;       // Signal (+1.0 or -1.0) to help plot X axis
	std::vector<double>           _sgnY;       // Signal (+1.0 or -1.0) to help plot Y axis

	TestKey _char_to_key(const char * strTestKey);

}; // class TestSim


#endif
