/***********************************************************************************
 * LabTestSim - Laboratory Test Simulator using Elastoplastic models               *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>     *
 *                                                                                 *
 * This file is part of LabTestSim.                                                *
 *                                                                                 *
 * LabTestSim is free software; you can redistribute it and/or modify it under the *
 * terms of the GNU General Public License as published by the Free Software       *
 * Foundation; either version 2 of the License, or (at your option) any later      *
 * version.                                                                        *
 *                                                                                 *
 * LabTestSim is distributed in the hope that it will be useful, but WITHOUT ANY   *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.        *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License along with    *
 * LabTestSim; if not, write to the Free Software Foundation, Inc., 51 Franklin    *
 * Street, Fifth Floor, Boston, MA 02110-1301, USA                                 *
 ***********************************************************************************/

#ifndef LABTESTSIM_READMAT_H
#define LABTESTSIM_READMAT_H

#include <iostream>
#include <string>
#include <vector>

// external
#include "mechsys/parameters/parameters.h"

class ReadMat
{

	friend std::ostream & operator<< (std::ostream & os, ReadMat & rm);
	
public:
	// Constructor
	ReadMat(std::string XMATERIALS_FileName);
	// Get
	std::string GetErrors() { return _errors; }
	// Set
	bool SetPrms(MechSys::Parameters * prms, std::string MatKey);

private:
	bool                     _is_mat_file_ok;
	int                      _num_mats;
	std::vector<std::string> _key;
	std::vector<std::string> _desc;
	std::vector<double>      _lam; // 1
	std::vector<double>      _kap; // 2
	std::vector<double>      _nuu; // 3
	std::vector<double>      _rcs; // 4
	std::vector<double>      _enc; // 5
	std::vector<double>      _pnc; // 6
	std::vector<double>      _bet; // 7
	std::vector<double>      _cc1; // 8
	std::vector<double>      _cc2; // 9
	std::vector<double>      _dd1; // 10
	std::vector<double>      _dd2; // 11
	std::string              _errors;
	
}; // class ReadMat

#endif
