/***********************************************************************************
 * LabTestSim - Laboratory Test Simulator using Elastoplastic models               *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>     *
 *                                                                                 *
 * This file is part of LabTestSim.                                                *
 *                                                                                 *
 * LabTestSim is free software; you can redistribute it and/or modify it under the *
 * terms of the GNU General Public License as published by the Free Software       *
 * Foundation; either version 2 of the License, or (at your option) any later      *
 * version.                                                                        *
 *                                                                                 *
 * LabTestSim is distributed in the hope that it will be useful, but WITHOUT ANY   *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.        *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License along with    *
 * LabTestSim; if not, write to the Free Software Foundation, Inc., 51 Franklin    *
 * Street, Fifth Floor, Boston, MA 02110-1301, USA                                 *
 ***********************************************************************************/

#include <iostream>
#include <fstream>
#include <string>
#include <stdexcept>
#include <gtkmm/window.h>
#include "mywindow.h"

void throw_msg(char * msg)
{
	throw msg;
}

MyWindow::MyWindow(BaseObjectType * cobject, const Glib::RefPtr<Gnome::Glade::Xml> & refGlade)
	: Gtk::Window(cobject),
	  ref_Glade(refGlade),
	  entry_DATDIR  (0),
	  entry_MAT     (0),
	  cbox_TST      (0),
	  entry_NUM     (0),
	  cbox_MDL      (0),
	  entry_nDiv    (0),
	  entry_nOut    (0),
	  entry_maxEd   (0),
	  button_RunSim (0),
	  button_Plot   (0),
	  button_Exit   (0),
	  FileChooser   (0),
	  image_Plot    (0),
	  textview_nfo  (0),
	  textview_cal  (0),
	  notebook      (0),
	  statusbar     (0),
	  _pRunSim      (0)
{
	// Get Glade-instantiated widgets
	ref_Glade->get_widget("entry_DATDIR"  , entry_DATDIR);
	ref_Glade->get_widget("entry_MAT"     , entry_MAT);
	ref_Glade->get_widget("cbox_TST"      , cbox_TST);
	ref_Glade->get_widget("entry_NUM"     , entry_NUM);
	ref_Glade->get_widget("cbox_MDL"      , cbox_MDL);
	ref_Glade->get_widget("entry_nDiv"    , entry_nDiv);
	ref_Glade->get_widget("entry_nOut"    , entry_nOut);
	ref_Glade->get_widget("entry_maxEd"   , entry_maxEd);

	ref_Glade->get_widget("button_RunSim" , button_RunSim);
	ref_Glade->get_widget("button_Plot"   , button_Plot);
	ref_Glade->get_widget("button_Exit"   , button_Exit);

	ref_Glade->get_widget("FileChooser"   , FileChooser);
	ref_Glade->get_widget("image_Plot"    , image_Plot);
	ref_Glade->get_widget("textview_nfo"  , textview_nfo);
	ref_Glade->get_widget("textview_cal"  , textview_cal);
	ref_Glade->get_widget("notebook"      , notebook);
	ref_Glade->get_widget("statusbar"     , statusbar);

	// Check pointers
	if(!entry_DATDIR ) throw_msg("ERROR: entry_DATDIR not found!");
	if(!entry_MAT    ) throw_msg("ERROR: entry_MAT not found!");
	if(!cbox_TST     ) throw_msg("ERROR: cbox_TST not found!");
	if(!entry_NUM    ) throw_msg("ERROR: entry_NUM not found!");
	if(!cbox_MDL     ) throw_msg("ERROR: cbox_MDL not found!");
	if(!entry_nDiv   ) throw_msg("ERROR: entry_nDiv not found!");
	if(!entry_nOut   ) throw_msg("ERROR: entry_nOut not found!");
	if(!entry_maxEd  ) throw_msg("ERROR: entry_maxEd not found!");

	if(!button_RunSim) throw_msg("ERROR: button_RunSim not found!");
	if(!button_Plot  ) throw_msg("ERROR: button_Plot not found!");
	if(!button_Exit  ) throw_msg("ERROR: button_Exit not found!");

	if(!FileChooser  ) throw_msg("ERROR: FileChooser not found!");
	if(!image_Plot   ) throw_msg("ERROR: image_Plot not found!");
	if(!textview_nfo ) throw_msg("ERROR: textview_nfo not found!");
	if(!textview_cal ) throw_msg("ERROR: textview_cal not found!");
	if(!notebook     ) throw_msg("ERROR: notebook not found!");

	// Connect a signal handler
	button_RunSim->signal_clicked().connect(sigc::mem_fun(*this, &MyWindow::on_button_RunSim_clicked));
	button_Plot->signal_clicked().connect(sigc::mem_fun(*this, &MyWindow::on_button_Plot_clicked));
	button_Exit->signal_clicked().connect(sigc::mem_fun(*this, &MyWindow::on_button_Exit_clicked));
	FileChooser->signal_current_folder_changed().connect(sigc::mem_fun(*this, &MyWindow::on_FileChooser_current_folder_changed));
	FileChooser->signal_selection_changed().connect(sigc::mem_fun(*this, &MyWindow::on_FileChooser_selection_changed));
	FileChooser->signal_file_activated().connect(sigc::mem_fun(*this, &MyWindow::on_FileChooser_file_activated));

	// Set initial values
	cbox_TST->set_active(0);
	cbox_MDL->set_active(1);
}

void MyWindow::on_button_RunSim_clicked()
{  
	std::string tmp;
	int         row;

	// Text entries
	_inputdata.DATDIR.clear();
	_inputdata.DATDIR.append(entry_DATDIR->get_text());
	_inputdata.MAT.clear();
	_inputdata.MAT.append(entry_MAT->get_text());
	_inputdata.NUM.clear();
	_inputdata.NUM.append(entry_NUM->get_text());

	std::cout << _inputdata.DATDIR << std::endl;
	std::cout << entry_DATDIR->get_text() << std::endl;

	// Combobox
	row = cbox_TST->get_active_row_number();
	switch (row)
	{
		case 0:
			{
				_inputdata.TST.clear();
				_inputdata.TST.append("CTP");
				break;
			}
		case 1:
			{
				_inputdata.TST.clear();
				_inputdata.TST.append("TTT");
				break;
			}
	}
	row = cbox_MDL->get_active_row_number();
	switch (row)
	{
		case 0:
			{
				_inputdata.MDL.clear();
				_inputdata.MDL.append("subcam");
				break;
			}
		case 1:
			{
				_inputdata.MDL.clear();
				_inputdata.MDL.append("subtij");
				break;
			}
	}
		
	// Numerical entries
	tmp              = entry_nDiv->get_text();
	_inputdata.nDiv  = atoi(tmp.c_str());
	tmp              = entry_nOut->get_text();
	_inputdata.nOut  = atoi(tmp.c_str());
	tmp              = entry_maxEd->get_text();
	_inputdata.maxEd = atoi(tmp.c_str());
	_inputdata.SetFilenames();

	// RunSim
	if (!(*_pRunSim)(_inputdata))
	{
		std::cout << "Some error occurred during RunSim :(\n";
		statusbar->push("Some error occurred during RunSim :(");
	}
	else
	{
		// nfo file
		std::ifstream nfo_file(_inputdata.nfoFN.c_str(),std::ios::in);
		if (nfo_file)
		{
			std::cout << "File <" << _inputdata.nfoFN << "> OK :)\n";
			char buffer[256];
			_textbuffer = Gtk::TextBuffer::create();
			while(!nfo_file.eof())
			{
				nfo_file.getline(buffer,256);
				_textbuffer->insert_at_cursor(buffer);
				_textbuffer->insert_at_cursor("\n");
			}
			textview_nfo->set_buffer(_textbuffer);
			nfo_file.close();
		}
		else
			std::cout << "ERROR: Could not open file <" << _inputdata.nfoFN << "> :(\n";
		// cal file
		std::ifstream cal_file(_inputdata.calFN.c_str(),std::ios::in);
		if (cal_file)
		{
			std::cout << "File <" << _inputdata.calFN << "> OK :)\n";
			char buffer[256];
			_textbuffer = Gtk::TextBuffer::create();
			while(!cal_file.eof())
			{
				cal_file.getline(buffer,256);
				_textbuffer->insert_at_cursor(buffer);
				_textbuffer->insert_at_cursor("\n");
			}
			textview_cal->set_buffer(_textbuffer);
			cal_file.close();
		}
		else
			std::cout << "ERROR: Could not open file <" << _inputdata.calFN << "> :(\n";
		// Show view .nfo
		std::cout << "Simulation succeeded :)\n";
		statusbar->push("Simulation succeeded :)");
		notebook->set_current_page(2);
	}
}

void MyWindow::on_button_Plot_clicked()
{  
	
	if (!(*_pGenPltFiles)(_inputdata))
	{
		std::cout << "Some error occurred during Plot :(\n";
		statusbar->push("Some error occurred during Plot :(");
	}
	else
	{
		Glib::RefPtr<Gdk::Pixbuf> tmp = Gdk::Pixbuf::create_from_file(_inputdata.pngFN);
		int    oriW     = tmp->get_width();
		int    oriH     = tmp->get_height();
		int    newW     = image_Plot->get_width();
		int    newH     = image_Plot->get_height();
		double scFactW  = static_cast<double>(newW)/static_cast<double>(oriW);
		double scFactH  = static_cast<double>(newH)/static_cast<double>(oriH);
		double scFactor = (scFactW<scFactH ? scFactW : scFactH);
		           newW = static_cast<int>((static_cast<double>(oriW))*scFactor);
		           newH = static_cast<int>((static_cast<double>(oriH))*scFactor);
		_image = tmp->scale_simple(newW,newH,Gdk::INTERP_BILINEAR);
		image_Plot->set(_image);
		std::cout << "Plot succeeded :)\n";
		statusbar->push("Plot succeeded :)");
		notebook->set_current_page(1);
	}
}

void MyWindow::on_button_Exit_clicked()
{  
	//std::cout << "on_button_Exit_clicked :)\n";
	hide();
}

void MyWindow::on_FileChooser_current_folder_changed()
{
	//std::cout << "on_FileChooser_current_folder_changed :)\n";
}

void MyWindow::on_FileChooser_selection_changed()
{
	std::string folder;
	folder = FileChooser->get_current_folder();
	entry_DATDIR->set_text(folder);
}

void MyWindow::on_FileChooser_file_activated()
{
	//std::cout << "on_FileChooser_file_activated :)\n";
}
