/***********************************************************************************
 * LabTestSim - Laboratory Test Simulator using Elastoplastic models               *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>     *
 *                                                                                 *
 * This file is part of LabTestSim.                                                *
 *                                                                                 *
 * LabTestSim is free software; you can redistribute it and/or modify it under the *
 * terms of the GNU General Public License as published by the Free Software       *
 * Foundation; either version 2 of the License, or (at your option) any later      *
 * version.                                                                        *
 *                                                                                 *
 * LabTestSim is distributed in the hope that it will be useful, but WITHOUT ANY   *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.        *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License along with    *
 * LabTestSim; if not, write to the Free Software Foundation, Inc., 51 Franklin    *
 * Street, Fifth Floor, Boston, MA 02110-1301, USA                                 *
 ***********************************************************************************/

#ifndef LABTESTSIM_MYWINDOW_H
#define LABTESTSIM_MYWINDOW_H

// gtkmm
#include <gtkmm/window.h>
#include <gtkmm/entry.h>
#include <gtkmm/combobox.h>
#include <gtkmm/button.h>
#include <gtkmm/filechooserwidget.h>
#include <gtkmm/image.h>
#include <gtkmm/textview.h>
#include <gtkmm/notebook.h>
#include <gtkmm/statusbar.h>

// gdkmm
#include <gdkmm/pixbuf.h>

// libglademm
#include <libglademm.h>

// others
#include "../inputdata.h"

class MyWindow : public Gtk::Window
{
public:
	MyWindow(BaseObjectType * cobject, const Glib::RefPtr<Gnome::Glade::Xml> & refGlade);
	virtual ~MyWindow() {}

	// Set function pointers
	void SetFunPtrs(bool (*pRunSim)(InputData & ID),
	                bool (*pGenPltFiles)(InputData & ID))
	{
		     _pRunSim = pRunSim;
		_pGenPltFiles = pGenPltFiles;
	}

protected:
	Glib::RefPtr<Gnome::Glade::Xml> ref_Glade;

	Gtk::Entry        * entry_DATDIR;
	Gtk::Entry        * entry_MAT;
	Gtk::ComboBox     * cbox_TST;
	Gtk::Entry        * entry_NUM;
	Gtk::ComboBox     * cbox_MDL;
	Gtk::Entry        * entry_nDiv;
	Gtk::Entry        * entry_nOut;
	Gtk::Entry        * entry_maxEd;

	Gtk::Button   * button_RunSim;
	Gtk::Button   * button_Plot;
	Gtk::Button   * button_Exit;

	Gtk::FileChooserWidget * FileChooser;
	Gtk::Image    * image_Plot;
	Gtk::TextView * textview_nfo;
	Gtk::TextView * textview_cal;

	Gtk::Notebook  * notebook;
	Gtk::Statusbar * statusbar;
	
	// Function pointers (that really do what the program intents to do)
	bool (*_pRunSim)(InputData & ID);
	bool (*_pGenPltFiles)(InputData & ID);

	// Callbacks
	void on_button_RunSim_clicked();
	void on_button_Plot_clicked();
	void on_button_Exit_clicked();
	void on_FileChooser_current_folder_changed();
	void on_FileChooser_selection_changed();
	void on_FileChooser_file_activated();

private:
	InputData                     _inputdata;
	Glib::RefPtr<Gtk::TextBuffer> _textbuffer;
	Glib::RefPtr<Gdk::Pixbuf>     _image;
	
}; // MyWindow

#endif // LABTESTSIM_MYWINDOW_H
