/***********************************************************************************
 * LabTestSim - Laboratory Test Simulator using Elastoplastic models               *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>     *
 *                                                                                 *
 * This file is part of LabTestSim.                                                *
 *                                                                                 *
 * LabTestSim is free software; you can redistribute it and/or modify it under the *
 * terms of the GNU General Public License as published by the Free Software       *
 * Foundation; either version 2 of the License, or (at your option) any later      *
 * version.                                                                        *
 *                                                                                 *
 * LabTestSim is distributed in the hope that it will be useful, but WITHOUT ANY   *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.        *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License along with    *
 * LabTestSim; if not, write to the Free Software Foundation, Inc., 51 Franklin    *
 * Street, Fifth Floor, Boston, MA 02110-1301, USA                                 *
 ***********************************************************************************/

#include <stdexcept>
#include <iostream>
#include <fstream>
#include "gui.h"
#include "../inputdata.h"

using namespace std;

bool RunSim(InputData & ID)
{
	cout << "Should run simulation now ....\n";
	cout << "Data received:\n";
	cout << "DATDIR  =  " << ID.DATDIR << endl;
	cout << "MAT     =  " << ID.MAT    << endl;
	cout << "TST     =  " << ID.TST    << endl;
	cout << "NUM     =  " << ID.NUM    << endl;
	cout << "MDL     =  " << ID.MDL    << endl;
	cout << "nDiv    =  " << ID.nDiv   << endl;
	cout << "nOut    =  " << ID.nOut   << endl;
	cout << "maxEd   =  " << ID.maxEd  << endl;
	cout << "Filenames:" << endl;
	cout << "XMatFN  =  " << ID.XMatFN << endl;
	cout << "PatFN  =  "  << ID.PatFN  << endl;
	cout << "DatFN  =  "  << ID.DatFN  << endl;
	cout << "nfoFN  =  "  << ID.nfoFN  << endl;
	cout << "calFN  =  "  << ID.calFN  << endl;
	cout << "pltFN  =  "  << ID.pltFN  << endl;
	cout << "epsFN  =  "  << ID.epsFN  << endl;
	cout << "pngFN  =  "  << ID.pngFN  << endl;
	cout << endl;

	// write files
	ofstream nfo_file(ID.nfoFN.c_str(),ios::out);
	if (nfo_file)
	{
		for (int i=0; i<10; ++i) nfo_file << "nfo file ;)\n";
		nfo_file.close();
		cout << "file <" << ID.nfoFN << "> written\n";
	}
	ofstream cal_file(ID.calFN.c_str(),ios::out);
	if (cal_file)
	{
		for (int i=0; i<10; ++i) cal_file << "cal file ;)\n";
		cal_file.close();
		cout << "file <" << ID.calFN << "> written\n";
	}
	ofstream plt_file(ID.pltFN.c_str(),ios::out);
	if (plt_file)
	{
		for (int i=0; i<10; ++i) plt_file << "plt file ;)\n";
		plt_file.close();
		cout << "file <" << ID.pltFN << "> written\n";
	}
	
	return true;
}

bool GenPltFiles(InputData & ID)
{
	ID.epsFN.clear();
	ID.epsFN.append("test.png");
	ID.pngFN.clear();
	ID.pngFN.append("test.png");
	return true;
}

int main(int argc, char **argv)
{
	try
	{
		Gui gui(argc, argv, &RunSim, &GenPltFiles);
	}
	catch (std::exception & e)
	{
		std::cout << "Exception: " << e.what() << std::endl;
	}
	return 0;
}
