/***********************************************************************************
 * LabTestSim - Laboratory Test Simulator using Elastoplastic models               *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>     *
 *                                                                                 *
 * This file is part of LabTestSim.                                                *
 *                                                                                 *
 * LabTestSim is free software; you can redistribute it and/or modify it under the *
 * terms of the GNU General Public License as published by the Free Software       *
 * Foundation; either version 2 of the License, or (at your option) any later      *
 * version.                                                                        *
 *                                                                                 *
 * LabTestSim is distributed in the hope that it will be useful, but WITHOUT ANY   *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.        *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License along with    *
 * LabTestSim; if not, write to the Free Software Foundation, Inc., 51 Franklin    *
 * Street, Fifth Floor, Boston, MA 02110-1301, USA                                 *
 ***********************************************************************************/

#ifndef LABTESTSIM_INPUTDATA_H
#define LABTESTSIM_INPUTDATA_H

#include <string>

class InputData
{
public:
	// Input from console/GUI
	std::string DATDIR;// Directory with xmaterials.dat and test's trajectories args[1]
	std::string MAT;   // {FO1,FO2,FO4,FO8, FNW,FCH, TSD,PSD}                   args[2]
	std::string TST;   // {CTX,CTP,CTA,CTR, TTX,TTP, HCY,PSA}                   args[3]
	std::string NUM;   // 01...NN                                               args[4]
	std::string MDL;   // {subcam,subtij}                                       args[5]
	int         nDiv;  // Number of divisions for each path (ndiv>=1)           args[6]
	int         nOut;  // Number of output for each path (1<=nout<=ndiv)        args[7]
	double      maxEd; // Max Value for deviatoric strain ed (%) (maxEd>0%)     args[8]

	// Filenames
	std::string XMatFN;
	std::string PatFN;
	std::string DatFN;
	std::string nfoFN;
	std::string calFN;
	std::string pltFN;
	std::string epsFN;
	std::string pngFN;

	// SetFilenames
	void SetFilenames()
	{
		XMatFN.clear();
		XMatFN.append(DATDIR);
		XMatFN.append("/xmaterials.dat");

		std::string tmp(DATDIR);
		tmp.append("/");
		tmp.append(MAT); tmp.append("/");
		tmp.append(TST); tmp.append("/");
		tmp.append(NUM);

		PatFN.clear();
		PatFN.append(tmp);
		PatFN.append(".pat");

		DatFN.clear();
		DatFN.append(tmp);
		DatFN.append(".dat");

		tmp.clear();
		tmp.append(MAT); tmp.append(".");
		tmp.append(TST); tmp.append(".");
		tmp.append(NUM); tmp.append(".");
		tmp.append(MDL);

		nfoFN.clear();
		nfoFN.append(tmp);
		nfoFN.append(".nfo");

		calFN.clear();
		calFN.append(tmp);
		calFN.append(".cal");

		pltFN.clear();
		pltFN.append(tmp);
		pltFN.append(".plt");

		epsFN.clear();
		epsFN.append(tmp);
		epsFN.append(".eps");

		pngFN.clear();
		pngFN.append(tmp);
		pngFN.append(".png");

	} // SetFilenames()

}; // class InputData

#endif
