/*************************************************************************************
 * MechSys - A C++ library to simulate (Continuum) Mechanical Systems                *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>       *
 *                                                                                   *
 * This file is part of MechSys.                                                     *
 *                                                                                   *
 * MechSys is free software; you can redistribute it and/or modify it under the      *
 * terms of the GNU General Public License as published by the Free Software         *
 * Foundation; either version 2 of the License, or (at your option) any later        *
 * version.                                                                          *
 *                                                                                   *
 * MechSys is distributed in the hope that it will be useful, but WITHOUT ANY        *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A   *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.          *
 *                                                                                   *
 * You should have received a copy of the GNU General Public License along with      *
 * MechSys; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, *
 * Fifth Floor, Boston, MA 02110-1301, USA                                           *
 *************************************************************************************/

#include <cmath>
#include "../base/mechsys.h"
#include "charinvs.h"

namespace MechSys
{

void CharInvs::_calculate_charinvs(const Tensr2 & T)
{
	double trT = T[0]+T[1]+T[2];
	Tensr2 TT;
	tensor_mult(T,T,TT);

	double trTT = TT[0]+TT[1]+TT[2];
	Tensr2 TTT;
	tensor_mult(T,TT,TTT);

	double trTTT = TTT[0]+TTT[1]+TTT[2];

	_I[0] = trT;
	_I[1] = (pow(trT,2.0) - trTT)/2.0;
	_I[2] = trTTT/3.0 - trTT*trT/2.0 + pow(trT,3.0)/6.0;
}

}; // namespace MechSys
