/*************************************************************************************
 * MechSys - A C++ library to simulate (Continuum) Mechanical Systems                *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>       *
 *                                                                                   *
 * This file is part of MechSys.                                                     *
 *                                                                                   *
 * MechSys is free software; you can redistribute it and/or modify it under the      *
 * terms of the GNU General Public License as published by the Free Software         *
 * Foundation; either version 2 of the License, or (at your option) any later        *
 * version.                                                                          *
 *                                                                                   *
 * MechSys is distributed in the hope that it will be useful, but WITHOUT ANY        *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A   *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.          *
 *                                                                                   *
 * You should have received a copy of the GNU General Public License along with      *
 * MechSys; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, *
 * Fifth Floor, Boston, MA 02110-1301, USA                                           *
 *************************************************************************************/

#include <cmath>
#include "straininvs.h"

namespace MechSys
{

bool StrainInvs::Get_ev_ed (double & ev, double & ed)
{
	double sq2 = sqrt(2.0);
	double   s = pow(_eps[0]-_eps[1],2.0)
		       + pow(_eps[1]-_eps[2],2.0)
			   + pow(_eps[2]-_eps[0],2.0)
		       + 6.0*pow(_eps[3]/sq2,2.0)
			   + 6.0*pow(_eps[4]/sq2,2.0)
			   + 6.0*pow(_eps[5]/sq2,2.0);
	ev = _eps[0]+_eps[1]+_eps[2];
	ed = 2.0*sqrt(s/2.0)/3.0;
	return true;
}

}; // namespace MechSys
