/*************************************************************************************
 * MechSys - A C++ library to simulate (Continuum) Mechanical Systems                *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>       *
 *                                                                                   *
 * This file is part of MechSys.                                                     *
 *                                                                                   *
 * MechSys is free software; you can redistribute it and/or modify it under the      *
 * terms of the GNU General Public License as published by the Free Software         *
 * Foundation; either version 2 of the License, or (at your option) any later        *
 * version.                                                                          *
 *                                                                                   *
 * MechSys is distributed in the hope that it will be useful, but WITHOUT ANY        *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A   *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.          *
 *                                                                                   *
 * You should have received a copy of the GNU General Public License along with      *
 * MechSys; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, *
 * Fifth Floor, Boston, MA 02110-1301, USA                                           *
 *************************************************************************************/

#include <iostream>
#include "../base/mechsys.h"
#include "../models/intvars.h"
#include "../models/nlelastic.h"
#include "../models/genericep.h"
#include "feuler.h"

namespace MechSys
{

bool SchForwardEuler<NlElastic>::StressUpdate(NlElastic * model, const Tensr2 & Deps, Tensr2 & Dsig)
{
	//std::cout << model->HighGradients() << std::endl;
	std::cout << "NlElastic\n";
	std::cout << "ID = " << GetID() << std::endl;
	std::cout << "_sig = \n" << model->_sig << std::endl;
	_num_calls++;
	return true;
}

bool SchForwardEuler<GenericEP>::StressUpdate(GenericEP * model, const Tensr2 & Deps, Tensr2 & Dsig)
{
	IntVars z_ini(model->_z.nIVLS(), model->_z.nIVns());
	//z_ini = model->_z;
	
	Tensr2  de = Deps/_num_div;
	Tensr2  ds;
	IntVars dz(model->_z.nIVLS(), model->_z.nIVns());
	Dsig.Clear();
	for (int i=0; i<_num_div; ++i)
	{
		model->_dstress_given_dstrain(de,ds,dz);
		model->_sig = model->_sig + ds;
		model->_z   = model->_z   + dz;
		if (!model->_update_state()) return false;
		Dsig = Dsig + ds;
	}

	//std::cout << "Dz = " << (model->_z - z_ini) << std::endl;
	
	_num_calls++;
	return true;
}

}; // namespace MechSys
