/*************************************************************************************
 * MechSys - A C++ library to simulate (Continuum) Mechanical Systems                *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>       *
 *                                                                                   *
 * This file is part of MechSys.                                                     *
 *                                                                                   *
 * MechSys is free software; you can redistribute it and/or modify it under the      *
 * terms of the GNU General Public License as published by the Free Software         *
 * Foundation; either version 2 of the License, or (at your option) any later        *
 * version.                                                                          *
 *                                                                                   *
 * MechSys is distributed in the hope that it will be useful, but WITHOUT ANY        *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A   *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.          *
 *                                                                                   *
 * You should have received a copy of the GNU General Public License along with      *
 * MechSys; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, *
 * Fifth Floor, Boston, MA 02110-1301, USA                                           *
 *************************************************************************************/

#ifndef MEULER_H
#define MEULER_H

#include "../base/mechsys.h"
#include "../models/nlelastic.h"
#include "../models/genericep.h"
#include "lawinteg.h"

namespace MechSys
{

template<typename ModelType>
class SchModifiedEuler : public LawIntegScheme<ModelType>
{
public:
	SchModifiedEuler(double STOL)
		: _max_it(1000),
		  _STOL(STOL),
		  _nss(0),
		  _min_nss(1000000),
		  _max_nss(0),
		  _tot_nss(0),
		  _dTini(0.001),
		  _mMin(0.01),
		  _mMax(10)
	{}
	SchemeID GetID()     const { return ME; }
	int      GetNss()    const { return _nss; }
	int      GetMinNss() const { return _min_nss; }
	int      GetMaxNss() const { return _max_nss; }
	int      GetTotNss() const { return _tot_nss; }
	void     ResetStat()
	{
		LawIntegScheme<ModelType>::ResetStat();
		    _nss = 0;
		_min_nss = 1000000;
		_max_nss = 0;
		_tot_nss = 0;
	}
	bool StressUpdate(NlElastic * model, const Tensr2 & Deps, Tensr2 & Dsig);
	bool StressUpdate(GenericEP * model, const Tensr2 & Deps, Tensr2 & Dsig);
private:
	int    _max_it;
	double _STOL;
	int    _nss;     // number of sub-steps
	int    _min_nss; // minimum number of sub-steps
	int    _max_nss; // minimum number of sub-steps
	int    _tot_nss; // total number of sub-steps
	double _dTini;   // Initial value of T
	double _mMin;    // minimum value for the multiplier m
	double _mMax;    // maximum value for the multiplier m
}; // class ModifiedEuler

}; // namespace MechSys

#endif
