/*************************************************************************************
 * MechSys - A C++ library to simulate (Continuum) Mechanical Systems                *
 * Copyright (C) 2005 Dorival de Moraes Pedroso <dorival_pedroso em yahoo.com>       *
 *                                                                                   *
 * This file is part of MechSys.                                                     *
 *                                                                                   *
 * MechSys is free software; you can redistribute it and/or modify it under the      *
 * terms of the GNU General Public License as published by the Free Software         *
 * Foundation; either version 2 of the License, or (at your option) any later        *
 * version.                                                                          *
 *                                                                                   *
 * MechSys is distributed in the hope that it will be useful, but WITHOUT ANY        *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A   *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.          *
 *                                                                                   *
 * You should have received a copy of the GNU General Public License along with      *
 * MechSys; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, *
 * Fifth Floor, Boston, MA 02110-1301, USA                                           *
 *************************************************************************************/

#include <iostream>
#include <cmath>
#include <cassert>

#include "matrix.h"
#include "jacobirot.h"

using namespace std;

void set_sigma(LinAlg::Matrix & Sigma)
{
	Sigma(0,0)=1.0; Sigma(0,1)=1.0;  Sigma(0,2)=1.0;
	                Sigma(1,1)=1.0;  Sigma(1,2)=1.0;
	                                 Sigma(2,2)=1.0;
	
	//Sigma(0,0)=1.0; Sigma(0,1)=0.001;  Sigma(0,2)=0.0;
	//                Sigma(1,1)=1.0;  Sigma(1,2)=0.0;
	//                                 Sigma(2,2)=1.0;
	
	//Sigma(0,0)=4.0; Sigma(0,1)=5.0;  Sigma(0,2)=6.0;
	//                Sigma(1,1)=8.0;  Sigma(1,2)=7.0;
	//                                 Sigma(2,2)=9.0;
	Sigma(1,0)=Sigma(0,1); 
	Sigma(2,0)=Sigma(0,2);
	Sigma(2,1)=Sigma(1,2);
}

void calc_eigenprojs(LinAlg::Matrix & Q, LinAlg::Matrix P[3])
{
	assert(Q.Rows()==3);
	assert(Q.Cols()==3);
	for (int k=0; k<3; ++k)
		for (int i=0; i<3; ++i)
		for (int j=0; j<3; ++j)
			P[k](i,j) = Q(i,k) * Q(j,k);
}

int main()
{
	LinAlg::Matrix A(3,3);
	LinAlg::Matrix Q(3,3);
	LinAlg::Matrix TMP(3,3);
	LinAlg::Matrix * P = new LinAlg::Matrix [3] (3,3); // Eigenprojectors

	set_sigma(A);
	//cout << "Enter A: ";
	//cin >> A;
	cout << "A = \n" << A << std::endl;

	LinAlg::Matrix AA(3,3); AA=A;
	int itrs = LinAlg::JacobiRot(A,Q);
	cout << "Iterations = " << itrs << endl;
	cout << "A = \n"        << A    << endl;
	cout << "Q = \n"        << Q    << endl;

	calc_eigenprojs(Q,P);
	TMP.SetValues(0.0);
	for (int i=0; i<3; ++i)
	for (int j=0; j<3; ++j)
		TMP(i,j) = TMP(i,j) + A(0,0)*P[0](i,j)
			                + A(1,1)*P[1](i,j)
							+ A(2,2)*P[2](i,j);
	cout << "Sum{eigenvals * eigenprojs} = \n" << TMP << endl;

	delete [] P;
	return 0;
}
